/**********************************************************************
*  2011 Microchip Technology Inc.
*
* FileName:        init_DMAC0.c
* Dependencies:    Header (.h) files if applicable, see below
* Processor:       dsPIC33Exxxx
* Compiler:        MPLAB C30 v3.30 or higher
*
* SOFTWARE LICENSE AGREEMENT:
* Microchip Technology Incorporated ("Microchip") retains all ownership and 
* intellectual property rights in the code accompanying this message and in all 
* derivatives hereto.  You may use this code, and any derivatives created by 
* any person or entity by or on your behalf, exclusively with Microchip's
* proprietary products.  Your acceptance and/or use of this code constitutes 
* agreement to the terms and conditions of this notice.
*
* CODE ACCOMPANYING THIS MESSAGE IS SUPPLIED BY MICROCHIP "AS IS".  NO 
* WARRANTIES, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED 
* TO, IMPLIED WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY AND FITNESS FOR A 
* PARTICULAR PURPOSE APPLY TO THIS CODE, ITS INTERACTION WITH MICROCHIP'S 
* PRODUCTS, COMBINATION WITH ANY OTHER PRODUCTS, OR USE IN ANY APPLICATION. 
*
* YOU ACKNOWLEDGE AND AGREE THAT, IN NO EVENT, SHALL MICROCHIP BE LIABLE, WHETHER 
* IN CONTRACT, WARRANTY, TORT (INCLUDING NEGLIGENCE OR BREACH OF STATUTORY DUTY), 
* STRICT LIABILITY, INDEMNITY, CONTRIBUTION, OR OTHERWISE, FOR ANY INDIRECT, SPECIAL, 
* PUNITIVE, EXEMPLARY, INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE, FOR COST OR EXPENSE OF 
* ANY KIND WHATSOEVER RELATED TO THE CODE, HOWSOEVER CAUSED, EVEN IF MICROCHIP HAS BEEN 
* ADVISED OF THE POSSIBILITY OR THE DAMAGES ARE FORESEEABLE.  TO THE FULLEST EXTENT 
* ALLOWABLE BY LAW, MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN ANY WAY RELATED TO 
* THIS CODE, SHALL NOT EXCEED THE PRICE YOU PAID DIRECTLY TO MICROCHIP SPECIFICALLY TO 
* HAVE THIS CODE DEVELOPED.
*
* You agree that you are solely responsible for testing the code and 
* determining its suitability.  Microchip has no obligation to modify, test, 
* certify, or support the code.
*
* REVISION HISTORY:
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* Date      Comments on this revision
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* 06/02/11	Initial Release for dsPIC33E
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*
* ADDITIONAL NOTES:
*
*
**********************************************************************/

#include "p33Exxxx.h"
    
/*---------------------------------------------------------------------
  Function Name: Init_DMAC0
  Description:   Initialize DMA Channel 0
  Inputs:        None
  Returns:       None
-----------------------------------------------------------------------*/
void Init_DMAC0( void )
{
	/* DMA buffer 1 Start address for DPSRAM Address */
	DMA0STAL = 0xD000;
	DMA0STAH = 0x0000;

	/* DMA buffer 2 Start address for DPSRAM Address */
	DMA0STBL = 0xD100;
	DMA0STBH = 0x0000;

	/* initialize DMA Peripheral SFR Address */
	DMA0PAD = (int) &ADC1BUF0;
	
	/* Set transfer count to 256 */
	DMA0CNT = 256;

	/* DMA Channel Setup  */
    /* Word transfer, Read from peripheral/Write to DPSRAM
       Interrupt when block transfer complete
       Automatic DMA transfer initiation by DMA request
       Register indirect
       One-shot mode, ping-pong disabled 
       ADC1 IRQ numer = 13 (D) */
	DMA0CON = 0x010D;
	
	/* set DMA CH0 interrupt priority level to 4 */
	IPC1bits.DMA0IP = 4;	
	/* reset DMA CH0 interrupt flag */ 
	IFS0bits.DMA0IF = 0;
	/* enable DMA CH0 interrupts */	  
	IEC0bits.DMA0IE = 1;

	/* enable DMA Channel 0 */
	DMA0CONbits.CHEN = 1;
}
