/**********************************************************************
*  2011 Microchip Technology Inc.
*
* FileName:        init_timer1.c
* Dependencies:    Header (.h) files if applicable, see below
* Processor:       dsPIC33Exxxx
* Compiler:        MPLAB C30 v3.30 or higher
*
* SOFTWARE LICENSE AGREEMENT:
* Microchip Technology Incorporated ("Microchip") retains all ownership and 
* intellectual property rights in the code accompanying this message and in all 
* derivatives hereto.  You may use this code, and any derivatives created by 
* any person or entity by or on your behalf, exclusively with Microchip's
* proprietary products.  Your acceptance and/or use of this code constitutes 
* agreement to the terms and conditions of this notice.
*
* CODE ACCOMPANYING THIS MESSAGE IS SUPPLIED BY MICROCHIP "AS IS".  NO 
* WARRANTIES, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED 
* TO, IMPLIED WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY AND FITNESS FOR A 
* PARTICULAR PURPOSE APPLY TO THIS CODE, ITS INTERACTION WITH MICROCHIP'S 
* PRODUCTS, COMBINATION WITH ANY OTHER PRODUCTS, OR USE IN ANY APPLICATION. 
*
* YOU ACKNOWLEDGE AND AGREE THAT, IN NO EVENT, SHALL MICROCHIP BE LIABLE, WHETHER 
* IN CONTRACT, WARRANTY, TORT (INCLUDING NEGLIGENCE OR BREACH OF STATUTORY DUTY), 
* STRICT LIABILITY, INDEMNITY, CONTRIBUTION, OR OTHERWISE, FOR ANY INDIRECT, SPECIAL, 
* PUNITIVE, EXEMPLARY, INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE, FOR COST OR EXPENSE OF 
* ANY KIND WHATSOEVER RELATED TO THE CODE, HOWSOEVER CAUSED, EVEN IF MICROCHIP HAS BEEN 
* ADVISED OF THE POSSIBILITY OR THE DAMAGES ARE FORESEEABLE.  TO THE FULLEST EXTENT 
* ALLOWABLE BY LAW, MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN ANY WAY RELATED TO 
* THIS CODE, SHALL NOT EXCEED THE PRICE YOU PAID DIRECTLY TO MICROCHIP SPECIFICALLY TO 
* HAVE THIS CODE DEVELOPED.
*
* You agree that you are solely responsible for testing the code and 
* determining its suitability.  Microchip has no obligation to modify, test, 
* certify, or support the code.
*
* REVISION HISTORY:
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* Date      Comments on this revision
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* 06/02/11	Initial Release for dsPIC33E
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*
* ADDITIONAL NOTES:
*
*
**********************************************************************/


#include "p33Exxxx.h"

/* Set SLEEP to 1 is dsPIC will enter sleep in main loop */
#define SLEEP  0

   
    
/*---------------------------------------------------------------------
  Function Name: Init_Timer1
  Description:   Initialize Timer1 for 1 second intervals
  Inputs:        None
  Returns:       None
-----------------------------------------------------------------------*/
void Init_Timer1( void )
{
	/* declare temp variable for CPU IPL storing */
	int current_cpu_ipl;
	
	/* ensure Timer 1 is in reset state */
	T1CON = 0;

	/* reset Timer 1 interrupt flag */
 	IFS0bits.T1IF = 0;
 	
 	/* set Timer1 interrupt priority level to 4 */
	IPC0bits.T1IP = 4;

	/* enable Timer 1 interrupt */
 	IEC0bits.T1IE = 1;
 	  	
	/* set Timer 1 period register */
	PR1 = 0x8000;

 	/* select external timer clock */
	T1CONbits.TCS = 1;

	/* disable interrupts for unlock sequence below */
//	SET_AND_SAVE_CPU_IPL(current_cpu_ipl, 7);	
	
 char a, b, c, *p;

 a = 2;
 b = 0x46;
 c = 0x57;
 p = (char *)&OSCCON;

	/* enable 32KHz Oscillator here 
       low byte unlock sequence and enable LP Oscillator */
 	asm volatile ("mov.b %1,[%0] \n"
                  "mov.b %2,[%0] \n"
                  "mov.b %3,[%0] \n" : /* no outputs */ : "r"(p), "r"(b), "r"(c),
                                                          "r"(a));
	
	/* restore CPU IPL value after executing unlock sequence */
//	RESTORE_CPU_IPL(current_cpu_ipl);
		 
 	/* enable Timer 1 and start the count */ 
	T1CONbits.TON = 1;
	
	
#if  SLEEP == 1
    /* If main loop will enter SLEEP mode then wait here 
       until Oscillator starts and Timer begins to count */
	while ( TMR1 < 2 );	
#endif	

}
