/**********************************************************************
*  2011 Microchip Technology Inc.
*
* FileName:        isr_timer1.c
* Dependencies:    Header (.h) files if applicable, see below
* Processor:       dsPIC33Exxxx
* Compiler:        MPLAB C30 v3.30 or higher
*
* SOFTWARE LICENSE AGREEMENT:
* Microchip Technology Incorporated ("Microchip") retains all ownership and 
* intellectual property rights in the code accompanying this message and in all 
* derivatives hereto.  You may use this code, and any derivatives created by 
* any person or entity by or on your behalf, exclusively with Microchip's
* proprietary products.  Your acceptance and/or use of this code constitutes 
* agreement to the terms and conditions of this notice.
*
* CODE ACCOMPANYING THIS MESSAGE IS SUPPLIED BY MICROCHIP "AS IS".  NO 
* WARRANTIES, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED 
* TO, IMPLIED WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY AND FITNESS FOR A 
* PARTICULAR PURPOSE APPLY TO THIS CODE, ITS INTERACTION WITH MICROCHIP'S 
* PRODUCTS, COMBINATION WITH ANY OTHER PRODUCTS, OR USE IN ANY APPLICATION. 
*
* YOU ACKNOWLEDGE AND AGREE THAT, IN NO EVENT, SHALL MICROCHIP BE LIABLE, WHETHER 
* IN CONTRACT, WARRANTY, TORT (INCLUDING NEGLIGENCE OR BREACH OF STATUTORY DUTY), 
* STRICT LIABILITY, INDEMNITY, CONTRIBUTION, OR OTHERWISE, FOR ANY INDIRECT, SPECIAL, 
* PUNITIVE, EXEMPLARY, INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE, FOR COST OR EXPENSE OF 
* ANY KIND WHATSOEVER RELATED TO THE CODE, HOWSOEVER CAUSED, EVEN IF MICROCHIP HAS BEEN 
* ADVISED OF THE POSSIBILITY OR THE DAMAGES ARE FORESEEABLE.  TO THE FULLEST EXTENT 
* ALLOWABLE BY LAW, MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN ANY WAY RELATED TO 
* THIS CODE, SHALL NOT EXCEED THE PRICE YOU PAID DIRECTLY TO MICROCHIP SPECIFICALLY TO 
* HAVE THIS CODE DEVELOPED.
*
* You agree that you are solely responsible for testing the code and 
* determining its suitability.  Microchip has no obligation to modify, test, 
* certify, or support the code.
*
* REVISION HISTORY:
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* Date      Comments on this revision
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* 06/02/11	Initial Release for dsPIC33E
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*
* ADDITIONAL NOTES:
*
*
**********************************************************************/

#include "p33Exxxx.h"


volatile unsigned char hours;
volatile unsigned char minutes;
volatile unsigned char seconds;
volatile unsigned char rtc_lcd_update;

void __builtin_btg(unsigned int *, unsigned int);

 

/*---------------------------------------------------------------------
  Function Name: _T1Interrupt
  Description:   Timer1 Interrupt Handler
  Inputs:        None
  Returns:       None
-----------------------------------------------------------------------*/
void __attribute__((__interrupt__,no_auto_psv)) _T1Interrupt( void )
{

	if ( seconds < 59 )          // is cummulative seconds < 59?
	{
		seconds++;               // yes, so increment seconds
	}
	else                         // else seconds => 59     
	{
		seconds = 0x00;          // reset seconds
		if ( minutes < 59 )      // is cummulative minutes < 59?
		{
			minutes++;           // yes, so updates minutes  
		}
		else                     // else minutes => 59
		{
			minutes = 0x00;      // reset minutes
			if ( hours < 23 )    // is cummulative hours < 23
			{
				hours ++;        // yes, so update hours
			}
			else
			{
				hours = 0x00;    // reset time
			}		  
		}
	}     

	/* set flag to update LCD */
	rtc_lcd_update = 1;
	
	/* Toggle LEDs at 1 Hz rate */
	__builtin_btg((unsigned int *)&LATA, 7);
	__builtin_btg((unsigned int *)&LATA, 6);
	__builtin_btg((unsigned int *)&LATA, 5);
	__builtin_btg((unsigned int *)&LATA, 4);
	__builtin_btg((unsigned int *)&LATA, 3);
	__builtin_btg((unsigned int *)&LATA, 2);	
	__builtin_btg((unsigned int *)&LATA, 1);

	/* reset Timer 1 interrupt flag */
 	IFS0bits.T1IF = 0;
}
