/**********************************************************************
*  2011 Microchip Technology Inc.
*
* FileName:        main_rtc.c
* Dependencies:    Header (.h) files if applicable, see below
* Processor:       dsPIC33Exxxx
* Compiler:        MPLAB C30 v3.30 or higher
*
* SOFTWARE LICENSE AGREEMENT:
* Microchip Technology Incorporated ("Microchip") retains all ownership and 
* intellectual property rights in the code accompanying this message and in all 
* derivatives hereto.  You may use this code, and any derivatives created by 
* any person or entity by or on your behalf, exclusively with Microchip's
* proprietary products.  Your acceptance and/or use of this code constitutes 
* agreement to the terms and conditions of this notice.
*
* CODE ACCOMPANYING THIS MESSAGE IS SUPPLIED BY MICROCHIP "AS IS".  NO 
* WARRANTIES, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED 
* TO, IMPLIED WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY AND FITNESS FOR A 
* PARTICULAR PURPOSE APPLY TO THIS CODE, ITS INTERACTION WITH MICROCHIP'S 
* PRODUCTS, COMBINATION WITH ANY OTHER PRODUCTS, OR USE IN ANY APPLICATION. 
*
* YOU ACKNOWLEDGE AND AGREE THAT, IN NO EVENT, SHALL MICROCHIP BE LIABLE, WHETHER 
* IN CONTRACT, WARRANTY, TORT (INCLUDING NEGLIGENCE OR BREACH OF STATUTORY DUTY), 
* STRICT LIABILITY, INDEMNITY, CONTRIBUTION, OR OTHERWISE, FOR ANY INDIRECT, SPECIAL, 
* PUNITIVE, EXEMPLARY, INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE, FOR COST OR EXPENSE OF 
* ANY KIND WHATSOEVER RELATED TO THE CODE, HOWSOEVER CAUSED, EVEN IF MICROCHIP HAS BEEN 
* ADVISED OF THE POSSIBILITY OR THE DAMAGES ARE FORESEEABLE.  TO THE FULLEST EXTENT 
* ALLOWABLE BY LAW, MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN ANY WAY RELATED TO 
* THIS CODE, SHALL NOT EXCEED THE PRICE YOU PAID DIRECTLY TO MICROCHIP SPECIFICALLY TO 
* HAVE THIS CODE DEVELOPED.
*
* You agree that you are solely responsible for testing the code and 
* determining its suitability.  Microchip has no obligation to modify, test, 
* certify, or support the code.
*
* REVISION HISTORY:
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* Date      Comments on this revision
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* 06/02/11	Initial Release for dsPIC33E
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*
* ADDITIONAL NOTES:  
*
* Simple demo program showing a RTC and ADC conversion on the LCD
* DMA code is included here but not fully tested.
*
* C30 Optimization Level: none
*
**********************************************************************/

#include "p33Exxxx.h"
#include "lcd.h"
#include "common.h"
#include "delay.h"

/** CONFIGURATION **************************************************/

#ifndef TESSY
_FOSCSEL(FNOSC_FRC);			
_FOSC(FCKSM_CSECMD & POSCMD_XT & OSCIOFNC_OFF & IOL1WAY_OFF);
_FWDT(FWDTEN_OFF);
_FPOR(FPWRT_PWR128 & BOREN_ON & ALTI2C1_ON & ALTI2C2_ON);
_FICD(ICS_PGD1 & RSTPRI_PF & JTAGEN_OFF);
#endif


void Update_LCD( void );
const char mytext[] =  " dsPIC33E Demo ";
const char mytext1[] = "Press S3 to cont";
const char time_msg[] = "Time 00: 00: 00 ";
const char adc_msg1[] =" RP5 = 0.00 Vdc  ";


int main ( void )
{
	/* Initialize some general use variables */
	hours, minutes, seconds = 0;
	rtc_lcd_update = 0;
	int temp;
return;
	DSRPAG = 1;
Nop();
Nop();
Nop();

   	// Configure the device PLL to obtain 60 MIPS operation. The crystal
    // frequency is 8MHz. Divide 8MHz by 2, multiply by 60 and divide by
    // 2. This results in Fosc of 120MHz. The CPU clock frequency is
    // Fcy = Fosc/2 = 60MHz. 
	PLLFBD = 58;				/* M  = 60	*/
	CLKDIVbits.PLLPOST = 0;		/* N1 = 2	*/
	CLKDIVbits.PLLPRE = 0;		/* N2 = 2	*/
	OSCTUN = 0;	

    /*	Initiate Clock Switch to Primary
     *	Oscillator with PLL (NOSC= 0x3)*/
    __builtin_write_OSCCONH(0x03);		
	__builtin_write_OSCCONL(0x01);
	while (OSCCONbits.COSC != 0x3); 
	while (_LOCK == 0);			/* Wait for PLL lock at 60 MIPS */

	/* set LEDs (D3-D10/RA0-RA7) drive state low */
	LATA = 0xFF00; 
	/* set LED pins (D3-D10/RA0-RA7) as outputs */
	TRISA = 0xFF00; 
	
	/* Set Switch 1 Input to Digital */
	_ANSD6 = 0;
	
	/* Initialize LCD Display */
	Init_LCD();

	/* Welcome message */
	home_clr();
	temp = DSRPAG;
	DSRPAG = __builtin_psvpage (mytext);
	puts_lcd( (unsigned char*) &mytext[0], sizeof(mytext) -1 );
	line_2();
	DSRPAG = __builtin_psvpage (mytext1);
	puts_lcd( (unsigned char*) &mytext1[0], sizeof(mytext1) -1 );
	DSRPAG = temp;

	/* wait here until switch S3 is pressed */
	while ( PORTDbits.RD6 );
		    
  	/* Initialize Timer 1 for 32KHz real-time clock operation */
    Init_Timer1();

    /* Initial LCD message for TOD */
	home_clr();
	temp = DSRPAG;
	DSRPAG = __builtin_psvpage (time_msg);
	puts_lcd( (unsigned char*) &time_msg[0], sizeof(time_msg) -1 );
 	line_2();
	DSRPAG = __builtin_psvpage (adc_msg1);
	puts_lcd( (unsigned char*) &adc_msg1[0], sizeof(adc_msg1) -1 );
	DSRPAG = temp;
          
    /* Initialize ADC  */
    Init_ADC();
    
    /* Infinite Loop */
    while ( 1 ) 
    { 
      /* check if time to update LCD with TOD data */  
      if ( rtc_lcd_update ) 
	  {
		 hexdec( hours );
		 Update_LCD();
		 rtc_lcd_update = 0;
      }	 	
      /* check if time to update LCD with ADC data */
  	  if ( adc_lcd_update ) 
  	  {
       	 line_2();
		 advolt( temp1 );
       	 cursor_right();
       	 cursor_right();
       	 cursor_right();  
       	 cursor_right();
       	 cursor_right();
       	 cursor_right();
       	 cursor_right();
		 lcd_data( adones );
       	 cursor_right();
	  	 lcd_data( adtens );
	  	 lcd_data( adhunds );	
	     adc_lcd_update = 0;
	  }
	}
}


/*---------------------------------------------------------------------
  Function Name: Update_LCD
  Description:   Update LCD for real-time clock data
  Inputs:        None
  Returns:       None
-----------------------------------------------------------------------*/
void Update_LCD( void )
{

   	/* position LCD cursor at column, row */
  	home_it();
    cursor_right();
    cursor_right();
    cursor_right();
    cursor_right();
    cursor_right();
	lcd_data(tens + 0x30);
	lcd_data(ones + 0x30);
    
    hexdec( minutes );
    /* position LCD cursor at column, row */
	cursor_right();
    cursor_right();
	lcd_data(tens + 0x30);
	lcd_data(ones + 0x30);
	 
  	hexdec( seconds );
	/* position LCD cursor at column, row */
	cursor_right();
    cursor_right();
	lcd_data(tens + 0x30);
	lcd_data(ones + 0x30);
   
}
